@@ -82,6 +82,7 @@ struct _ProcInfo
 	GSList		*children;
 
 	GdkPixbuf	*pixbuf;
+	gchar		*tooltip;
 	gchar		*name;
 	gchar		*user; /* allocated with g_string_chunk, don't free it ! */
 	gchar		*arguments;
@@ -96,6 +97,7 @@ struct _ProcInfo
 	guint64		memres;
 	guint64		memwritable;
 	guint64		memshared;
+	guint64		mem; /* estimated memory usage */
 	unsigned long	memxserver;
 
 	guint		pcpu; /* 0% - 100% */
